<?php
/**
 * @file
 * Defines AuthcacheEsiRequestBase
 *
 * Abstract base class implementing common request features for ESI handlers.
 */

abstract class AuthcacheEsiRequestBase extends AuthcacheP13nRequestBase {
  /**
   * Name of special http header used to pass the user id to the cache.
   */
  private $headername;

  /**
   * Construct new ESI request handler instance.
   *
   * When the config-key 'per-user-header' is set the value will be used as the
   * HTTP header name for passing the user id to the cache.
   */
  public function __construct($config) {
    parent::__construct($config);

    if (isset($config['per-user-header'])) {
      $this->headername = $config['per-user-header'];
    }
    else {
      $this->headername = 'X-Authcache-Per-User';
    }
  }

  /**
   * Set headers and send response to client.
   */
  public function sendResponse($req) {
    parent::sendResponse($req);
    $this->sendPerUserHeader();
  }

  /**
   * Put user-id into a custom http header.
   */
  protected function sendPerUserHeader() {
    global $user;

    if (!empty($this->headername)) {
      header($this->headername . ': ' . $user->uid);
    }
  }
}
