<?php
/**
 * @file
 * Defines AuthcacheP13nFragmentAssemblyBuilder
 */

class AuthcacheP13nFragmentAssemblyBuilder implements AuthcacheP13nContentBuilder, AuthcacheP13nRequestValidator {
  /**
   * A list of partial fragments indexed by parametr name.
   */
  protected $partials;

  /**
   * Construct new instance and handle the following config entries:
   *
   * - fragments: Key-value map of parameter names to fragment class names.
   */
  public function __construct($partials) {
    $this->partials = $partials;
  }

  /**
   * Validate request.
   *
   * Throw AuthcacheP13nRequestInvalidInput to abort a request.
   */
  public function validate($req) {
    // Normalize request parameters
    foreach ($req['a'] as $paramname => $params) {
      $params = empty($params) ? array() : static::mapAssoc($params);

      // Run validators
      if (!empty($this->partials[$paramname]['validator'])) {
        $params = $this->partials[$paramname]['validator']->validate($params);
      }

      $req['a'][$paramname] = $params;
    }

    return $req;
  }

  /**
   * Render response.
   */
  public function build($req) {
    global $user;

    $result = array();

    foreach ($req['a'] as $paramname => $params) {
      // Skip when there is no handler present
      if (empty($this->partials[$paramname]['renderer'])) {
        continue;
      }

      $partial = $this->partials[$paramname];

      // Run loader
      if (!empty($partial['loader'])) {
        $params = $partial['loader']->load($params);
      }

      foreach ($params as $key => $subject) {
        // Run access check
        if (!empty($partial['access']) && !$partial['access']->check($user, $key, $subject)) {
          throw new AuthcacheP13nRequestAccessDenied();
        }
        else {
          $result[$paramname][$key] = $partial['renderer']->render($key, $subject);
        }
      }
    }

    return $result;
  }

  protected static function mapAssoc($array) {
    // array_combine() fails with empty arrays:
    // http://bugs.php.net/bug.php?id=34857.
    return !empty($array) ? array_combine($array, $array) : array();
  }
}
