<?php
/**
 * @file
 * Defines AuthcacheP13nFragmentBuilder
 */

class AuthcacheP13nFragmentBuilder implements AuthcacheP13nContentBuilder, AuthcacheP13nRequestValidator {
  /**
   * @var AuthcacheP13nFragment
   */
  protected $fragment;

  /**
   * @var AuthcacheP13nFragmentValidator
   */
  protected $validator;

  /**
   * @var AuthcacheP13nFragmentLoader
   */
  protected $loader;

  /**
   * @var AuthcacheP13nFragmentAccess
   */
  protected $access;

  /**
   * Construct new instance and handle the following config entries:
   *
   * - fragment: The fragment class to use
   * - fragment validator: (optional) The validator class to use. If fragment 
   *   implements AuthcacheP13nFragmentValidator it is used instead.
   * - fragment loader: (optional) The loader class to use. If fragment 
   *   implements AuthcacheP13nFragmentLoader it is used instead.
   * - fragment access: (optional) The access checker class to use. If fragment
   *   implements AuthcacheP13nFragmentAccess it is used instead.
   */
  public function __construct($fragment, $validator, $loader, $access) {
    $this->fragment = $fragment;
    $this->validator = $validator;
    $this->loader = $loader;
    $this->access = $access;
  }

  /**
   * Validate request.
   *
   * Throw AuthcacheP13nRequestInvalidInput to abort a request.
   */
  public function validate($req) {
    // Normalize request parameter
    $param = empty($req['a']) ? array() : array($req['a'] => $req['a']);

    // Run validator
    if ($this->validator) {
      $param = $this->validator->validate($param);
    }

    $req['a'] = $param;

    return $req;
  }

  /**
   * Render response.
   */
  public function build($req) {
    global $user;

    $params = $req['a'];

    // Run loader
    if ($this->loader) {
      $params = $this->loader->load($params);
    }

    $key = key($params);
    $subject = current($params);

    // Run access check
    if ($this->access && !$this->access->check($user, $key, $subject)) {
      throw new AuthcacheP13nRequestAccessDenied();
    }
    else {
      return $this->fragment->render($key, $subject);
    }
  }
}
