<?php
/**
 * @file
 * Defines AuthcacheP13nSettingBuilder
 */

class AuthcacheP13nSettingBuilder implements AuthcacheP13nContentBuilder, AuthcacheP13nRequestValidator {
  /**
   * @var AuthcacheP13nSetting
   */
  protected $setting;

  /**
   * @var string
   */
  protected $target;

  /**
   * @var AuthcacheP13nSettingValidator
   */
  protected $validator;

  /**
   * @var AuthcacheP13nSettingAccess
   */
  protected $access;

  /**
   * Construct new instance and handle the following config entries:
   *
   * - setting: The setting class to use
   * - target: The name of the target attribute on Drupal.settings
   * - setting validator: (optional) The validator class to use. If setting 
   *   implements AuthcacheP13nSettingValidator it is used instead.
   * - setting access: (optional) The access checker class to use. If setting
   *   implements AuthcacheP13nSettingAccess it is used instead.
   */
  public function __construct($setting, $validator, $access, $target) {
    $this->setting = $setting;
    $this->validator = $validator;
    $this->access = $access;
    $this->target = $target;
  }

  /**
   * Validate request.
   *
   * Throw AuthcacheP13nRequestInvalidInput to abort a request.
   */
  public function validate($req) {
    // Normalize request parameter
    $req['a'] = empty($req['a']) ? NULL : $req['a'];

    // Run validator
    if ($this->validator) {
      $req['a'] = $this->validator->validate($req['a']);
    }

    return $req;
  }

  /**
   * Render response.
   */
  public function build($req) {
    global $user;

    $params = $req['a'];

    // Run access check
    if ($this->access && !$this->access->check($user, $params)) {
      throw new AuthcacheP13nRequestAccessDenied();
    }
    else {
      return array($this->target => $this->setting->get($params));
    }
  }
}
