<?php

class AuthcacheP13nTestRequestRegistryStub implements AuthcacheP13nRequestRegistry {
  /**
   * Return a map (path -> request-id)
   */
  public function routes() {
  }

  /**
   * Given a path return an appropriate request id
   */
  public function resolve($path) {
    switch ($path) {
    case 'test/path':
      return 'test/good';
    case 'test/bad':
      return 'test/bad';
    default:
      throw new AuthcacheP13nRequestNotFound();
    }
  }

  /**
   * Return the configuration for the given request
   */
  public function get($request_id) {
    switch ($request_id) {
    case 'test/good':
      return new AuthcacheP13nTestRequestHandlerStub;
    case 'test/bad':
      return new AuthcacheP13nTestRequestHandlerBadStub;
    default:
      throw new AuthcacheP13nRequestInvalidInput();
    }
  }

  /**
   * Rebuild info structure for requests.
   */
  public function rebuild() {
  }
}

class AuthcacheP13nTestRequestHandlerStub implements AuthcacheP13nRequestHandler {
  /**
   * Render and print the response according to the given parameters.
   */
  public function handle($params) {
    print serialize($params);
  }

  /**
   * Return a list of key-value pairs representing the default parameters for
   * this request.
   */
  public function defaults() {
    return array(
      'd' => 'test-defaults',
    );
  }
}

class AuthcacheP13nTestRequestHandlerBadStub implements AuthcacheP13nRequestHandler {
  /**
   * Render and print the response according to the given parameters.
   */
  public function handle($params) {
    print 'this line is expected to be discarded';
    switch ($params['error']) {
    case 'not_found':
      throw new AuthcacheP13nRequestNotFound;
    case 'invalid_input':
      throw new AuthcacheP13nRequestInvalidInput;
    case 'access_denied':
      throw new AuthcacheP13nRequestAccessDenied;
    case 'server_error':
      throw new AuthcacheP13nRequestException;
    default:
      throw new Exception;
    }
  }

  /**
   * Return a list of key-value pairs representing the default parameters for
   * this request.
   */
  public function defaults() {
    return array();
  }
}
